Slash
=====

.. image:: https://secure.travis-ci.org/vmalloc/slash.png?branch=master,dev

.. image:: https://coveralls.io/repos/vmalloc/slash/badge.png?branch=dev

.. image:: https://pypip.in/d/slash/badge.png

.. image:: https://pypip.in/v/slash/badge.png

Slash is a testing framework written in Python for testing complex projects. 

**Homepage**: `http://vmalloc.github.io/slash`

**Documentation**: `https://slash.readthedocs.org/en/latest/`
